@@ -27,7 +27,7 @@ from itools.csv import CSVFile, Property
 from itools.datatypes import Boolean, Integer, String, Unicode, Enumerate
 from itools.gettext import MSG
 from itools.i18n import format_datetime
-from itools.handlers import merge_dics
+from itools.handlers import merge_dicts
 from itools.uri import encode_query, Reference
 from itools.web import BaseView, BaseForm, STLForm
 from itools.web import INFO, ERROR
@@ -83,9 +83,9 @@ class StoreSearchMenu(ContextMenu):
 
     title = MSG(u'Remember this search')
     template = '/ui/tracker/menu_remember.xml'
-    query_schema = merge_dics(StoredSearchFile.schema,
-                              search_name=String,
-                              search_title=Unicode)
+    query_schema = merge_dicts(StoredSearchFile.schema,
+                               search_name=String,
+                               search_title=Unicode)
 
     def get_namespace(self, resource, context):
         # This search exists ?
@@ -179,7 +179,7 @@ class TrackerViewMenu(ContextMenu):
 ###########################################################################
 class Tracker_NewInstance(DBResource_NewInstance):
 
-    schema = merge_dics(
+    schema = merge_dicts(
         DBResource_NewInstance.schema,
         product=Unicode(mandatory=True))
 
@@ -273,8 +273,8 @@ class Tracker_View(BrowseForm):
 
 
     def get_query_schema(self):
-        return merge_dics(BrowseForm.get_query_schema(self),
-                          self.tracker_schema)
+        return merge_dicts(BrowseForm.get_query_schema(self),
+                           self.tracker_schema)
 
 
     def GET(self, resource, context):
@@ -457,9 +457,9 @@ class Tracker_Search(BaseSearchForm, Tracker_View):
 class Tracker_RememberSearch(BaseForm):
 
     access = 'is_allowed_to_edit'
-    schema = merge_dics(StoredSearchFile.schema,
-                        search_name=String,
-                        search_title=Unicode(mandatory=True))
+    schema = merge_dicts(StoredSearchFile.schema,
+                         search_name=String,
+                         search_title=Unicode(mandatory=True))
 
 
     def GET(self, resource, context):
@@ -550,53 +550,21 @@ class Tracker_GoToIssue(BaseView):
 
 
 
-class Tracker_ExportToText(Tracker_View):
+class Tracker_ExportToCSVForm(Tracker_View):
 
-    template = '/ui/tracker/export_to_text.xml'
+    template = '/ui/tracker/export_to_csv.xml'
     external_form = True
 
     def get_query_schema(self):
-        return merge_dics(Tracker_View.get_query_schema(self),
-                          ids=String(multiple=True, default=[]),
-                          column_selection=String(multiple=True,
-                                                  default=['title']))
+        schema = Tracker_View.get_query_schema(self)
+        schema['ids'] = String(multiple=True, default=[])
+        return schema
+
 
     def get_namespace(self, resource, context):
         namespace = Tracker_View.get_namespace(self, resource, context)
         query = context.query
 
-        # Column Selector
-        selection = query['column_selection']
-        export_columns = columns[2:] + [columns[1]]
-        namespace['columns'] = [
-            {'name': name, 'title': title, 'checked': name in selection}
-            for name, title in export_columns ]
-
-        # Text
-        items = self.get_items(resource, context)
-        items = self.sort_and_batch(resource, context, items)
-        selected_items = query['ids']
-        if selected_items:
-            items = [ x for x in items if x.name in selected_items ]
-        items = [ get_issue_informations(resource, x) for x in items ]
-        # Create the text
-        lines = []
-        for item in items:
-            name = item['name']
-            line = [u'#%s' % name]
-            for x in selection:
-                value = item[x]
-                if type(value) is unicode:
-                    pass
-                elif type(value) is str:
-                    value = unicode(value, 'utf-8')
-                else:
-                    value = unicode(value)
-                line.append(value)
-            line = u'\t'.join(line)
-            lines.append(line)
-        namespace['text'] = u'\n'.join(lines)
-
         # Insert query parameters as hidden input fields
         parameters = []
         schema = Tracker_View.get_query_schema(self)
@@ -604,25 +572,15 @@ class Tracker_ExportToText(Tracker_View):
             if name in namespace:
                 continue
             value = query[name]
-            if value:
-                datatype = schema.get(name, String)
-                parameters.append(HiddenWidget(name).to_html(datatype, value))
+            datatype = schema[name]
+            widget = HiddenWidget(name)
+            if datatype.multiple is True:
+                for value in value:
+                    parameters.append(widget.to_html(datatype, value))
+            elif value:
+                parameters.append(widget.to_html(datatype, value))
         namespace['search_parameters'] = parameters
 
-        # Ok
-        return namespace
-
-
-
-class Tracker_ExportToCSVForm(Tracker_View):
-
-    template = '/ui/tracker/export_to_csv.xml'
-    external_form = True
-
-
-    def get_namespace(self, resource, context):
-        namespace = Tracker_View.get_namespace(self, resource, context)
-        namespace['query'] = encode_query(context.uri.query)
         return namespace
 
 
@@ -685,6 +643,58 @@ class Tracker_ExportToCSV(BaseView):
 
 
 
+class Tracker_ExportToText(Tracker_ExportToCSVForm):
+
+    template = '/ui/tracker/export_to_text.xml'
+
+    def get_query_schema(self):
+        schema = Tracker_ExportToCSVForm.get_query_schema(self)
+        schema['column_selection'] = String(multiple=True, default=['title'])
+        return schema
+
+
+    def get_namespace(self, resource, context):
+        namespace = Tracker_ExportToCSVForm.get_namespace(self, resource,
+                                                          context)
+        query = context.query
+
+        # Column Selector
+        selection = query['column_selection']
+        export_columns = columns[2:] + [columns[1]]
+        namespace['columns'] = [
+            {'name': name, 'title': title, 'checked': name in selection}
+            for name, title in export_columns ]
+
+        # Text
+        items = self.get_items(resource, context)
+        items = self.sort_and_batch(resource, context, items)
+        selected_items = query['ids']
+        if selected_items:
+            items = [ x for x in items if x.name in selected_items ]
+        items = [ get_issue_informations(resource, x) for x in items ]
+        # Create the text
+        lines = []
+        for item in items:
+            name = item['name']
+            line = [u'#%s' % name]
+            for x in selection:
+                value = item[x]
+                if type(value) is unicode:
+                    pass
+                elif type(value) is str:
+                    value = unicode(value, 'utf-8')
+                else:
+                    value = unicode(value)
+                line.append(value)
+            line = u'\t'.join(line)
+            lines.append(line)
+        namespace['text'] = u'\n'.join(lines)
+
+        # Ok
+        return namespace
+
+
+
 class Tracker_ChangeSeveralBugs(Tracker_View):
 
     access = 'is_allowed_to_view'
